#!/bin/bash

# This is install/upgrade script for ksrs technical software

baseip=0
if [ -n "$1" ] ; then
  baseip=$1
fi

MainKSRSDir=/opt/ksrs-tech
KSRSTechGUIDir=gui
KSRSTechGUIBin=KARSControl

dep_path="../Dependencies/Linux"

#KSRSTechGUI="../NEW_BUILD/x86-64-linux-qt4.8.7-debug/TechControl"
#KSRSTechGUILib="../NEW_BUILD/x86-64-linux-qt4.8.7-debug/Lib"

if ! [ -d "../NEW_BUILD/x86-64-linux-qt4.8.7-release/TechControl" ]; then
qtver="qt5.12.5"
else
qtver="qt4.8.7"
fi

KSRSTechGUI="../NEW_BUILD/x86-64-linux-$qtver-release/TechControl"
KSRSTechGUILib="../NEW_BUILD/x86-64-linux-$qtver-release/Lib"


#KSRSCollectorScr=..TechControl/Modules/Linux/Fedora

TechKSRSUnits="../TechControl/Modules/Linux/Fedora"


TermKSRSLibs="/etc/ld.so.conf.d/ksrs-terminal.conf"
TechKSRSLibs="/etc/ld.so.conf.d/ksrs-tech.conf"

service_path="/usr/lib/systemd/system"

KSRSSudoers=/etc/sudoers.d/ksrs
TechKSRSSudoers="$dep_path/ksrs_sudoers"

udev_rules_path=/etc/udev/rules.d
AMountUdevRulesFilename="99-ksrs-media-auto-mount.rules"
#AMountUdevRulesSrc="$dep_path/$AMountUdevRulesFilename"
udisks_udev_rules_file="99-ksrs-udisks2.rules"
udisks_polkit_path=/etc/polkit-1/rules.d
udisks_polkit_rules_file="10-ksrs-udisks2.rules"

ksrsmounter_file="ksrsmounter"
ksrsmounter_install_path="/usr/local/bin"
ksrsmounter_service_name="$ksrsmounter_file.service"
ksrsmounter_service_content="[Unit]
Description=KSRS auto mounter

[Service]
Type=simple
ExecStart=$ksrsmounter_install_path/$ksrsmounter_file

[Install]
WantedBy=multi-user.target"


KSRSGUIUser=user0
KSRSAutoGUI=KARSTech.desktop
KSRSAutoGUIContent="[Desktop Entry]
Type=Application
Exec=/opt/ksrs-tech/gui/KARSControl 2>/dev/null
Hidden=false
NoDisplay=false
X-GNOME-Autostart-enabled=true
Name[ru_RU]=KSRS Technical Control
Name=KSRS Technical Control
Comment[ru_RU]=
Comment="

KSRSGUI=KARSControl.desktop
KSRSGUIContent="[Desktop Entry]
Version=1.0
Terminal=false
Exec=/opt/ksrs-tech/gui/KARSControl 2>/dev/null
Name[ru_RU]=KSRS Technical Control
Name=KSRS Technical Control
Comment[ru_RU]=
Comment=
Categories=Application"


KSRSAutoLoginContent="[base]
autologin=user0
session=/usr/bin/openbox-session
greeter=/usr/libexec/lxdm-greeter-gtk

[server]
arg=/usr/bin/X -background none vt1

[display]
gtk_theme=Clearlooks
bg=/usr/share/backgrounds/default.png
bottom_pane=1
lang=1
keyboard=0
theme=Industrial

[input]

[userlist]
disable=0
white=
black=
"

GUIServiceName="lemz-ksrs-control"
KSRSGUIService="/usr/lib/systemd/system/$GUIServiceName.service"
GUIServiceContent="[Unit]
Description=Start KSRS Control GUI.
After=display-manager.service network.service network-online.target

[Service]
User=user0
Group=user0
Type=simple
Environment=DISPLAY=:0
Environment=XAUTHORITY=/home/user0/.Xauthority
ExecStart=/opt/ksrs-tech/gui/KARSControl --service
ExecStop=/opt/ksrs-tech/gui/KARSControl --closeall
Restart=on-failure
StandardOutput=null

[Install]
WantedBy=graphical.target"

KSRSUdevPrinterRules="KERNEL==\"lp*\", ATTRS{idVendor}==\"04b8\", ATTRS{idProduct}==\"0046\", MODE:=\"0666\""

#KSRSCollectorServiceName=lemz-snmp-collector

SNMPTrapServiceName="snmptrapd"
KSRSsnmptrapdConfContent="ignoreAuthFailure yes
disableAuthorization yes
snmpTrapdAddr UDP:162
traphandle default /usr/bin/php /usr/bin/$KSRSCollectorTrapFwdFile"
SNMPTRAPDMAINPID='$MAINPID'
KSRSSNMPTRAPDSevice="/usr/lib/systemd/system/$SNMPTrapServiceName.service"
SNMPTRAPDServiceContent="[Unit]
Description=Simple Network Management Protocol (SNMP) Trap Daemon.
After=syslog.target network.target

[Service]
Type=notify
EnvironmentFile=-/etc/sysconfig/snmptrapd
ExecStart=/usr/sbin/snmptrapd -Ln -f -One -n
ExecReload=/bin/kill -HUP $SNMPTRAPDMAINPID

[Install]
WantedBy=multi-user.target"

SNMPRegex="^net-snmp-[0-9]+"

SNMPServiceName="snmpd"
KSRSsnmpdConfContent="trap2sink 192.168.12.$((baseip+1)) public
trap2sink 192.168.12.$((baseip+2)) public
rwcommunity public 192.168.12.$((baseip+1))
rwcommunity public 192.168.12.$((baseip+2))
disk /
disk /opt
disk /var
createUser internal
rouser internal
agentSecName internal
iquerySecName internal
defaultMonitors yes
notificationEvent  linkUpTrap    linkUp   ifIndex ifAdminStatus ifOperStatus
notificationEvent  linkDownTrap  linkDown ifIndex ifAdminStatus ifOperStatus

monitor  -r 10 -e linkUpTrap   \"Generate linkUp\"   ifOperStatus != 2
monitor  -r 10 -e linkDownTrap \"Generate linkDown\" ifOperStatus == 2"
SNMPDMAINPID='$MAINPID'
KSRSSNMPAgent="/usr/lib/systemd/system/$SNMPServiceName.service"
SNMPDServiceContent="[Unit]
Description=Simple Network Management Protocol (SNMP) Daemon.
After=syslog.target network.target

[Service]
Type=notify
EnvironmentFile=-/etc/sysconfig/snmpd
ExecStart=/usr/sbin/snmpd -Ln -f
ExecReload=/bin/kill -HUP $SNMPDMAINPID

[Install]
WantedBy=multi-user.target"

# 0. Check for root access
printf "checking for user access.. "
if [ $(whoami) != "root" ]; then
  echo "fail [need root access]"
  exit 1
else
  echo "ok"
fi

# 1. Check dependencies
#look packages
printf "checking for rpm dependences.. "
rpmList=$(rpm -qa | grep -e qt-4.8 -e qt-x11 -e qt-ibase -e qtwebkit -e net-snmp -e php -e lxdm -e openbox -e qt5-qtmultimedia -e qt5-qtwebengine -e qt5-qtbase-ibase -e firebird)
rpmQTMain=0
rpmQTX11=0
rpmQTIBase=0
rpmQTWebKit=0
rpmPHP=0
rpmSNMP=0
rpmSNMPAgent=0
rpmSNMPUtils=0
rpmLXDM=0
rpmOPENBOX=0
rpmQTMultimedia=0
rpmQTWebengine=0
rpmQTBaseIbase=0
rpmFIREBIRD=0
for aPacket in $rpmList; do
  if [ "$rpmQTMain" -eq 0 ]; then
    if [[ $aPacket == qt-4.8*.x86_64 ]]; then
      rpmQTMain=1
      continue
    fi
  fi
  if [ "$rpmQTX11" -eq 0 ]; then
    if [[ $aPacket == qt-x11*.x86_64 ]]; then
      rpmQTX11=1
      continue
    fi
  fi
  if [ "$rpmQTIBase" -eq 0 ]; then
    if [[ $aPacket == qt-ibase*.x86_64 ]]; then
      rpmQTIBase=1
      continue
    fi
  fi
  if [ "$rpmQTWebKit" -eq 0 ]; then
    if [[ $aPacket == qtwebkit*.x86_64 ]]; then
      rpmQTWebKit=1
      continue
    fi
  fi
  if [ "$rpmPHP" -eq 0 ]; then
    if [[ $aPacket == php*.x86_64 ]]; then
      rpmPHP=1
      continue
    fi
  fi  
  if [ "$rpmSNMP" -eq 0 ]; then
    if [[ $aPacket =~ $SNMPRegex  ]]; then
      rpmSNMP=1
      continue
    fi
  fi
  if [ "$rpmSNMPAgent" -eq 0 ]; then
    if [[ $aPacket == net-snmp-agent*.x86_64 ]]; then
      rpmSNMPAgent=1
      continue
    fi
  fi  
  if [ "$rpmSNMPUtils" -eq 0 ]; then
    if [[ $aPacket == net-snmp-utils*.x86_64 ]]; then
      rpmSNMPUtils=1
      continue
    fi
  fi
  if [ "$rpmLXDM" -eq 0 ]; then
    if [[ $aPacket == lxdm-* ]]; then
      rpmLXDM=1
      continue
    fi
  fi
  if [ "$rpmOPENBOX" -eq 0 ]; then
    if [[ $aPacket == openbox-* ]]; then
      rpmOPENBOX=1
      continue
    fi
  fi
  if [ "$rpmQTMultimedia" -eq 0 ]; then
    if [[ $aPacket == qt5-qtmultimedia*.x86_64 ]]; then
      rpmQTMultimedia=1
      continue
    fi
  fi
  if [ "$rpmQTWebengine" -eq 0 ]; then
    if [[ $aPacket == qt5-qtwebengine*.x86_64 ]]; then
      rpmQTWebengine=1
      continue
    fi
  fi
  if [ "$rpmQTBaseIbase" -eq 0 ]; then
    if [[ $aPacket == qt5-qtbase-ibase*.x86_64 ]]; then
      rpmQTBaseIbase=1
      continue
    fi
  fi
  
  
  if [ "$rpmFIREBIRD" -eq 0 ]; then
    if [[ $aPacket == firebird-classic* ]]; then
      rpmFIREBIRD=1
      continue
    fi
  fi
  if [ "$rpmFIREBIRD" -eq 0 ]; then
    if [[ $aPacket == firebird-superclassic* ]]; then
      rpmFIREBIRD=1
      continue
    fi
  fi
  if [ "$rpmFIREBIRD" -eq 0 ]; then
    if [[ $aPacket == firebird-superserver* ]]; then
      rpmFIREBIRD=1
      continue
    fi
  fi
done
if [ "$rpmQTWebKit" -eq 0 -o "$rpmQTIBase" -eq 0 -o "$rpmQTMain" -eq 0 -o "$rpmQTX11" -eq 0 -o "$rpmPHP" -eq 0 -o "$rpmSNMP" -eq 0 -o "$rpmSNMPAgent" -eq 0 -o "$rpmSNMPUtils" -eq 0 -o "$rpmLXDM" -eq 0 -o "$rpmOPENBOX" -eq 0 -o "$rpmQTMultimedia" -eq 0 -o "$rpmQTWebengine" -eq 0 -o "$rpmQTBaseIbase" -eq 0 ]; then
  echo "fail"
  if [ "$rpmQTMain" -eq 0 ]; then
    echo "package <qt> is not accessible"
  fi
  if [ "$rpmQTX11" -eq 0 ]; then
    echo "package <qt-x11> is not accessible"
  fi
  if [ "$rpmQTIBase" -eq 0 ]; then
    echo "package <qt-ibase> is not accessible"
  fi
  if [ "$rpmQTWebKit" -eq 0 ]; then
    echo "package <qtwebkit> is not accessible"
  fi
  if [ "$rpmPHP" -eq 0 ]; then
    echo "package <php> is not accessible"
  fi
  if [ "$rpmSNMP" -eq 0 ]; then
    echo "package <net-snmp> is not accessible"
  fi
  if [ "$rpmSNMPAgent" -eq 0 ]; then
    echo "package <net-snmp-agent> is not accessible"
  fi 
  if [ "$rpmSNMPUtils" -eq 0 ]; then
    echo "package <net-snmp-utils> is not accessible"
  fi 
  if [ "$rpmLXDM" -eq 0 ]; then
    echo "package <lxdm> is not accessible"
  fi
  if [ "$rpmOPENBOX" -eq 0 ]; then
    echo "package <openbox> is not accessible"
  fi
  if [ "$rpmQTMultimedia" -eq 0 ]; then
    echo "package <qt5-qtmultimedia> is not accessible"
  fi
  if [ "$rpmQTWebengine" -eq 0 ]; then
    echo "package <qt5-qtwebengine> is not accessible"
  fi
   if [ "$rpmQTBaseIbase" -eq 0 ]; then
    echo "package <qt5-qtbase-ibase> is not accessible"
  fi
#  if [ "$rpmFIREBIRD" -eq 0 ]; then
#    echo "package <firebird-{some server}> is not accessible"
#  fi  
  exit 1
fi
echo "ok"

# 2. (re)Place binary files
#create main binary directory (if need)
if ! [ -d $MainKSRSDir ]; then
  printf "create main directory for binary ($MainKSRSDir).. "
  if [ $(mkdir -m755 $MainKSRSDir) ]; then
    echo "fail"
    exit 1
  else
    echo "ok"
  fi
fi
#create gui directory (if need)
if ! [ -d "$MainKSRSDir/$KSRSTechGUIDir" ]; then
  printf "create gui directory for binary ($MainKSRSDir/$KSRSTechGUIDir).. "
  if [ $(mkdir -m777 $MainKSRSDir/$KSRSTechGUIDir) ]; then
    echo "fail"
    exit 1
  else
    echo "ok"
  fi
fi

#copy files
#gui
ksrsFiles=$(ls $TechKSRSUnits)
for afile in $ksrsFiles; do
  if ! [ -d $MainKSRSDir/$KSRSTechGUIDir/$afile ]; then
    rm -r $MainKSRSDir/$KSRSTechGUIDir/$afile || rm -f $MainKSRSDir/$KSRSTechGUIDir/$afile
  fi
  printf "copy technical gui file ($afile).. "
  if [ $(cp -fr $TechKSRSUnits/$afile $MainKSRSDir/$KSRSTechGUIDir) ]; then
    echo "fail"
    exit 1
  else
    echo "ok"
    printf "chmod technical gui file ($afile) to 777.. "
    chmod -f 777 $MainKSRSDir/$KSRSTechGUIDir/$afile
    if [ $? -ne 0 ]; then
      echo "fail"
      exit 1
    else
      echo "ok"
    fi
  fi
done


#gui new
#ksrsFiles=$(ls $TechKSRSUnits)
#for afile in $ksrsFiles; do
  if ! [ -d $MainKSRSDir/$KSRSTechGUIDir/KARSControl ]; then
    rm -r $MainKSRSDir/$KSRSTechGUIDir/KARSControl || rm -f $MainKSRSDir/$KSRSTechGUIDir/KARSControl
  fi
  printf "copy technical gui file (KARSControl).. "
  if [ $(cp -fr $KSRSTechGUI/KARSControl $MainKSRSDir/$KSRSTechGUIDir) ]; then
    echo "fail"
    exit 1
  else
    echo "ok"
    printf "chmod technical gui file (KARSControl) to 777.. "
    chmod -f 777 $MainKSRSDir/$KSRSTechGUIDir/KARSControl
    if [ $? -ne 0 ]; then
      echo "fail"
      exit 1
    else
      echo "ok"
    fi
  fi
#done


#gui libs
ksrsFiles=$(ls $KSRSTechGUILib)
for afile in $ksrsFiles; do
  if ! [ -d $MainKSRSDir/$KSRSTechGUIDir/$afile ]; then
    rm -r $MainKSRSDir/$KSRSTechGUIDir/$afile || rm -f $MainKSRSDir/$KSRSTechGUIDir/$afile
  fi
  printf "copy technical gui file ($afile).. "
  if [ $(cp -fr $KSRSTechGUILib/$afile $MainKSRSDir/$KSRSTechGUIDir) ]; then
    echo "fail"
    exit 1
  else
    echo "ok"
    printf "chmod technical gui file ($afile) to 777.. "
    chmod -f 777 $MainKSRSDir/$KSRSTechGUIDir/$afile
    if [ $? -ne 0 ]; then
      echo "fail"
      exit 1
    else
      echo "ok"
    fi
  fi
done



# 3. (re)Register libs - terminal libs has priority!

if ! [ -f $TermKSRSLibs ]; then
  if ! [ -f $TechKSRSLibs ]; then
    printf "create ($TechKSRSLibs) with content ($MainKSRSDir/$KSRSTechGUIDir).. "
    if [ $(echo "$MainKSRSDir/$KSRSTechGUIDir" > $TechKSRSLibs) ]; then
      echo "fail"
      exit 1
    else
      echo "ok"
    fi
  else
    tmpStr=$(cat $TechKSRSLibs)
    if [ "$tmpStr" != "$MainKSRSDir/$KSRSTechGUIDir" ]; then
      printf "rewrite library references($tmpStr) to ($MainKSRSDir/$KSRSTechGUIDir).. "
      if [ $(echo "$MainKSRSDir/$KSRSTechGUIDir" > $TechKSRSLibs) ]; then
        echo "fail"
        exit 1
      else
        echo "ok"
      fi
    fi
  fi
  printf "renew library references.. "
  if [ $(ldconfig) ]; then
    echo "fail"
    exit 1
  else
    echo "ok"
  fi
else
  echo "warning: found ($TermKSRSLibs) library - gui will use it"
fi

# 4. (re)Configure SNMP(TRAP) daemon
printf "checking snmptrapd configuration.. "
snmptrapdConfContent=$(cat /etc/snmp/snmptrapd.conf)
if ! [ "bm$KSRSsnmptrapdConfContent" == "bm$snmptrapdConfContent" ]; then
  echo "incorrect"
  printf "rewrite snmptrapd configuration.. "
  if [ $(echo "$KSRSsnmptrapdConfContent" > /etc/snmp/snmptrapd.conf) ]; then
    echo "fail"
    exit 1
  fi
  echo "ok"
else
  echo "correct"
fi
printf "checking snmpd configuration.. "
if ! [ -f "/etc/snmp/snmpd.conf" ]; then
#snmpdConfContent=$(cat /etc/snmp/snmpd.conf)
#if ! [ "bm$KSRSsnmpdConfContent" == "bm$snmpdConfContent" ]; then
#  echo "incorrect"
  printf "write snmpd configuration.. "
  if [ $(echo "$KSRSsnmpdConfContent" > /etc/snmp/snmpd.conf) ]; then
    echo "fail"
    exit 1
  fi
  echo "ok"
else
  echo "correct"
fi


runStatus=$(systemctl is-active $SNMPTrapServiceName)
if [ "$runStatus" == "active" ]; then
  printf "stop $SNMPTrapServiceName service.. "
  if [ $(systemctl stop $SNMPTrapServiceName) ]; then
    echo "fail"
    exit 1
  fi
  echo "ok"
fi
autoStatus=$(2>/dev/null systemctl is-enabled $SNMPTrapServiceName)
if [ "$autoStatus" == "enabled" ]; then
  printf "disable $SNMPTrapServiceName service.. "
  if [ $(systemctl -q disable $SNMPTrapServiceName) ]; then
    echo "fail"
    exit 1
  fi
  echo "ok"
fi
runStatus=$(systemctl is-active $SNMPServiceName)
if [ "$runStatus" == "active" ]; then
  printf "stop $SNMPServiceName service.. "
  if [ $(systemctl stop $SNMPServiceName) ]; then
    echo "fail"
    exit 1
  fi
  echo "ok"
fi
autoStatus=$(2>/dev/null systemctl is-enabled $SNMPServiceName)
if [ "$autoStatus" == "enabled" ]; then
  printf "disable $SNMPServiceName service.. "
  if [ $(systemctl -q disable $SNMPServiceName) ]; then
    echo "fail"
    exit 1
  fi
  echo "ok"
fi

## sudoers configuration
printf "copy sudoers configuration file.. "
if [ $(cp -f $TechKSRSSudoers $KSRSSudoers) ]; then
    echo "fail" 
    exit 1
  else
    echo "ok"
    printf "chmod sudoers ksrs file to 755.. "
    chmod -f 755 $KSRSSudoers
    if [ $? -ne 0 ]; then
	echo "fail"
	exit 1
    else
	echo "ok"
    fi
fi

## openbox theme
printf "renew openbox theme decoration.. "
rcfile=/etc/xdg/openbox/rc.xml
bksuffix=_ksrs
if [ -e ${rcfile} ] && [ ! -e ${rcfile}${bksuffix} ]; then
  param=titleLayout
  value=L
  sed -i${bksuffix} "s|\(<${param}>\)[^<>]*\(</${param}>\)|\1${value}\2|g" $rcfile
  echo "ok"
else
  echo "not needed"
fi

## openbox volume key bindings
printf "add openbox volume keys bindings.. "
rcfile=/etc/xdg/openbox/rc.xml
bindscheck=$(cat ${rcfile} | grep -i 'XF86AudioRaiseVolume' | head -1)
if [ -e ${rcfile} ] && [[ -z "${bindscheck// }" ]]; then
  param=keyboard
  value='<keybind key="XF86AudioRaiseVolume"><action name="Execute"><command>amixer -q sset PCM 3%+</command></action></keybind><keybind key="XF86AudioLowerVolume"><action name="Execute"><command>amixer -q sset PCM 3%-</command></action></keybind>'
  sed -i "s|\(</${param}>\)|${value}\1|g" $rcfile
  echo "ok"
else
  echo "not needed"
fi

## udev for usb flash drives automount patch
#printf "patching udev for usb flash drives automount.. "
#svc=/usr/lib/systemd/system/systemd-udevd.service
#bksuffix=_ksrs
##if [ -e ${svc} ] && [ ! -e ${svc}${bksuffix} ]; then
#if [ -e ${svc} ] ; then
#  param=MountFlags
#  value=shared
#  sed -i${bksuffix} "s|\(^${param}=\).*\($\)|\1${value}\2|g" $svc
#  echo "ok"
#else
#  echo "not needed"
#fi

## udev for usb flash drives automount rules
#printf "creating udev rules for usb flash drives automount.. "
#if [ $(cp -f -T $AMountUdevRulesSrc "$udev_rules_path/$AMountUdevRulesFilename") ]; then
#    echo "fail" 
#    exit 1
#  else
#    echo "ok"
#    printf "chmod ksrs usb flash automount udev rules file to 644.. "
#    if [ $(chmod -f 644 "$udev_rules_path/$AMountUdevRulesFilename") ]; then
#	echo "fail"
#	exit 1
#    else
#	echo "ok"
#    fi
#fi	           
printf "removing old udev rules for usb flash drives automount.. "
if [ -f "$udev_rules_path/$AMountUdevRulesFilename" ]; then
  rm -f $udev_rules_path/$AMountUdevRulesFilename
  if [ $? -ne 0 ]; then
    echo "fail"
  else
    echo "ok"
  fi
else 
  echo "not needed"
fi

## udisks for usb flash drives automount rules part 1
printf "creating udisks polkit rules for usb flash drives automount.. "
if [ $(cp -f -T $dep_path/$udisks_polkit_rules_file "$udisks_polkit_path/$udisks_polkit_rules_file") ]; then
    echo "fail" 
    exit 1
  else
    echo "ok"
    printf "chmod ksrs usb flash automount udisks polkit rules file to 644.. "
    if [ $(chmod -f 644 "$udisks_polkit_path/$udisks_polkit_rules_file") ]; then
	echo "fail"
	exit 1
    else
	echo "ok"
    fi
fi

## udisks for usb flash drives automount rules part 2
printf "creating udisks udev rules for usb flash drives automount.. "
if [ $(cp -f -T $dep_path/$udisks_udev_rules_file "$udev_rules_path/$udisks_udev_rules_file") ]; then
    echo "fail" 
    exit 1
  else
    echo "ok"
    printf "chmod ksrs usb flash automount udisks udev rules file to 644.. "
    if [ $(chmod -f 644 "$udev_rules_path/$udisks_udev_rules_file") ]; then
	echo "fail"
	exit 1
    else
	echo "ok"
    fi
fi

## ksrsmounter tool
printf "create ksrsmounter tool.. "
if [ $(cp -f -T $dep_path/$ksrsmounter_file $ksrsmounter_install_path/$ksrsmounter_file) ]; then
    echo "fail" 
    exit 1
  else
    echo "ok"
    printf "chmod ksrsmounter tool to 755.. "
    chmod -f 755 $ksrsmounter_install_path/$ksrsmounter_file
    if [ $? -ne 0 ]; then
	echo "fail"
	exit 1
    else
	echo "ok"
    fi
fi

## ksrsmounter service
if ! [ -f $service_path/$ksrsmounter_service_name ]; then
  printf "create $ksrsmounter_service_name.. "
else
  printf "renew $ksrsmounter_service_name.. "
fi
if [ $(echo "$ksrsmounter_service_content" > $service_path/$ksrsmounter_service_name) ]; then
  echo "fail"
  exit 1
fi
echo "ok"
printf "chmod ksrsmounter service to 644.. "
chmod -f 644 $service_path/$ksrsmounter_service_name
if [ $? -ne 0 ]; then
  echo "fail"
    exit 1
  else
    echo "ok"
fi


# 5. (re)Install services (if need)

runStatus=$(systemctl is-active $GUIServiceName)
if [ "$runStatus" == "active" ]; then
 printf "stop $GUIServiceName service.. "
if [ $(systemctl stop $GUIServiceName) ]; then
echo "fail"
exit 1
fi
echo "ok"
fi
autoStatus=$(2>/dev/null systemctl is-enabled $GUIServiceName)
if [ "$autoStatus" == "enabled" ]; then
printf "disable $GUIServiceName service.. "
if [ $(systemctl -q disable $GUIServiceName) ]; then
echo "fail"
exit 1
fi
echo "ok"
fi
	
			
if ! [ -f $KSRSGUIService ]; then
printf "create ($KSRSGUIService).. "
else
printf "renew ($KSRSGUIService).. "
fi
if [ $(echo "$GUIServiceContent" > $KSRSGUIService) ]; then
echo "fail"
exit 1
fi
echo "ok"


#stop if running and autorun
#runStatus=$(systemctl is-active $KSRSCollectorServiceName)
#if [ "$runStatus" == "active" ]; then
#  printf "stop $KSRSCollectorServiceName service.. "
#  if [ $(systemctl stop $KSRSCollectorServiceName) ]; then
#    echo "fail"
#    exit 1
#  fi
#  echo "ok"
#fi
#autoStatus=$(2>/dev/null systemctl is-enabled $KSRSCollectorServiceName)
#if [ "$autoStatus" == "enabled" ]; then
#  printf "disable $KSRSCollectorServiceName service.. "
#  if [ $(systemctl -q disable $KSRSCollectorServiceName) ]; then
#    echo "fail"
#    exit 1
#  fi
#  echo "ok"
#fi

#start services
#printf "starting $KSRSCollectorServiceName service.. "
#if [ $(systemctl start $KSRSCollectorServiceName) ]; then
#  echo "fail"
#  exit 1
#fi
#echo "ok"

# 6. autologin and autostart

#deleting gui control autostart file
if [ -f "/home/$KSRSGUIUser/.config/autostart/$KSRSAutoGUI" ]; then
  printf "deleting gui control user autostart file.. "
    if [ $(rm /home/$KSRSGUIUser/.config/autostart/$KSRSAutoGUI) ]; then
        echo "fail"
        exit 1
     else
      echo "ok"
    fi
fi

#printf "checking user <$KSRSGUIUser>.. " 
#if ! [ -d "/home/$KSRSGUIUser" ]; then 
#  echo "absent" 
#  printf "creating gui terminal user.. " 
#  if [ $(adduser $KSRSGUIUser --password 1234) ]; then 
#    echo "fail" 
#    exit 1 
#  else 
#    echo "ok" 
#  fi 
#else 
#  echo "exists" 
#fi 
#if ! [ -d "/home/$KSRSGUIUser/.config" ]; then 
#  printf "creating gui terminal user config directory.. " 
#  if [ $(mkdir /home/$KSRSGUIUser/.config) ]; then 
#    echo "fail" 
#    exit 1 
#  else 
#    echo "ok" 
#  fi 
#fi 
#if ! [ -d "/home/$KSRSGUIUser/.config/autostart" ]; then 
#  printf "creating gui terminal user autostart directory.. " 
#  if [ $(mkdir /home/$KSRSGUIUser/.config/autostart) ]; then 
#    echo "fail" 
#    exit 1 
#  else 
#    echo "ok" 
#  fi 
#fi 
#printf "renew gui terminal user autostart script.. " 
#if [ $(echo "$KSRSAutoGUIContent" > /home/$KSRSGUIUser/.config/autostart/$KSRSAutoGUI) ]; then 
#  echo "fail" 
#  exit 1 
#fi 
#echo "ok"

printf "renew gui control user desktop script.. "
if [ $(echo "$KSRSGUIContent" > /usr/share/applications/$KSRSGUI) ]; then
  echo "fail"
  exit 1
fi
echo "ok"

printf "renew gui terminal user autologin script.. "
if [ $(echo "$KSRSAutoLoginContent" > /etc/lxdm/lxdm.conf) ]; then
  echo "fail"
  exit 1
fi
echo "ok"
printf "renew systemd user level link.. "
if [ $(ln -sf /usr/lib/systemd/system/graphical.target /etc/systemd/system/default.target) ]; then
  echo "fail"
  exit 1
fi
echo "ok"
printf "allow printer access to all users.. "
if [ $(echo "$KSRSUdevPrinterRules" > /etc/udev/rules.d/90-cups-usb.rules) ]; then
  echo "fail"
  exit 1
fi
echo "ok"


#make snmptrapd service configuration
if ! [ -f $KSRSSNMPTRAPDSevice ]; then
  printf "create ($KSRSSNMPTRAPDSevice).. "
else
  printf "renew ($KSRSSNMPTRAPDSevice).. "
fi
if [ $(echo "$SNMPTRAPDServiceContent" > $KSRSSNMPTRAPDSevice) ]; then
  echo "fail"
  exit 1
fi
echo "ok"

#make snmpd service configuration
if ! [ -f $KSRSSNMPAgent ]; then
  printf "create ($KSRSSNMPAgent).. "
else
  printf "renew ($KSRSSNMPAgent).. "
fi
if [ $(echo "$SNMPDServiceContent" > $KSRSSNMPAgent) ]; then
  echo "fail"
  exit 1
fi
echo "ok"

#apply changes
printf "reload systemd daemons configuration.. "
if [ $(systemctl daemon-reload) ]; then
  echo "fail"
  exit 1
fi
echo "ok"

printf "reload udev rules.. "
if [ $(udevadm control --reload) ]; then
  echo "fail"
  exit 1
fi
echo "ok"

#setup autorun
#printf "enable $SNMPTrapServiceName service.. "
#if [ $(systemctl -q enable $SNMPTrapServiceName) ]; then
#  echo "fail"
#  exit 1
#fi
#echo "ok"

printf "enable $SNMPServiceName service.. "
if [ $(systemctl -q enable $SNMPServiceName) ]; then
  echo "fail"
  exit 1
fi
echo "ok"

printf "enable $GUIServiceName service.. "
if [ $(systemctl -q enable $GUIServiceName) ]; then
    echo "fail"
    exit 1
fi
echo "ok"

printf "enable $ksrsmounter_file service.. "
if [ $(systemctl -q disable $ksrsmounter_service_name) ]; then
  echo "fail"
  exit 1
fi
echo "ok"

#start services
#printf "starting $SNMPTrapServiceName service.. "
#if [ $(systemctl start $SNMPTrapServiceName) ]; then
#  echo "fail"
#  exit 1
#fi
#echo "ok"

printf "starting $SNMPServiceName service.. "
if [ $(systemctl start $SNMPServiceName) ]; then
  echo "fail"
  exit 1
fi
echo "ok"

printf "starting $GUIServiceName service.. "
if [ $(systemctl start $GUIServiceName) ]; then
    echo "fail"
    exit 1
fi
echo "ok"

printf "stopping $ksrsmounter_file service.. "
if [ $(systemctl stop $ksrsmounter_service_name) ]; then
  echo "fail"
  #exit 1
fi
echo "ok"


echo "Technical software setup completed successfully. Please reboot operating system!"
# normal exit
exit 0
